@@ -25,6 +25,8 @@
 
 #include <string.h>
 
+#include <libedataserver/e-data-server-util.h>
+
 #include <glib/gi18n-lib.h>
 
 #include <camel/camel-provider.h>
@@ -36,6 +38,19 @@
 static guint exchange_url_hash (gconstpointer key);
 static gint exchange_url_equal (gconstpointer a, gconstpointer b);
 
+#ifdef G_OS_WIN32
+
+static const char *
+get_localedir (void)
+{
+	return e_util_replace_prefix (PREFIX, e_util_get_cp_prefix (), CONNECTOR_LOCALEDIR);
+}
+
+#undef CONNECTOR_LOCALEDIR
+#define CONNECTOR_LOCALEDIR get_localedir ()
+
+#endif
+
 CamelProviderConfEntry exchange_conf_entries[] = {
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "mailcheck", NULL,
 	  N_("Checking for New Mail") },
@@ -76,7 +91,7 @@ CamelProviderConfEntry exchange_conf_entries[] = {
 	  N_("Only check for Junk messag_es in the Inbox folder"), "0" },
 	{ CAMEL_PROVIDER_CONF_HIDDEN, "auth-domain", NULL,
 	  NULL, "Exchange" },
-	 	
+
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	{ CAMEL_PROVIDER_CONF_END }
 };
@@ -94,7 +109,7 @@ static CamelProvider exchange_provider = {
 
 	CAMEL_URL_NEED_USER | CAMEL_URL_HIDDEN_AUTH | CAMEL_URL_HIDDEN_HOST,
 
-	exchange_conf_entries 
+	exchange_conf_entries
 
 	/* ... */
 };
